.. Copyright 2013-2022 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Reahl documentation
===================

Reahl comprises a number of projects that help with the development of
interactive web applications.

**Reahl-web** is a web application framework that allows a programmer to work
in terms of useful abstractions -- using a single programming language.
The details of how those abstractions are implemented using several
different web technologies are hidden and dealt with for the
programmer.

**Reahl-component** provides infrastructure for components in any application that can
also have their own database schemas, configuration, internationalisation and more.

The other projects support development of (mostly web) applications, regardless
of which web framework is used.


Introduction
------------

.. toctree::
   :maxdepth: 1

   overview
   whatchanged

Web framework (reahl-web)
-------------------------

.. toctree::
   :maxdepth: 1

   Tutorial <tutorial/index>
   howto/index

Other projects
--------------

.. toctree::
   :maxdepth: 1

   component/introduction
   browsertools/introduction
   tofu/introduction
   stubble/introduction

API Documentation
-----------------

.. toctree::
   :maxdepth: 1

   component/index
   web/index
   domain/index
   devtools/index
   devmanual/index
   browsertools/index
   tofu/index
   stubble/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

